# ramka

[![Tests](https://github.com/mateuszcisek/ramka/actions/workflows/tests.yaml/badge.svg)](https://github.com/mateuszcisek/ramka/actions/workflows/tests.yaml)
[![Linting](https://github.com/mateuszcisek/ramka/actions/workflows/linting.yaml/badge.svg)](https://github.com/mateuszcisek/ramka/actions/workflows/linting.yaml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/PyCQA/pylint)


ramka is a very small web framework written in Python.

## Documentation

Coming soon :)

## Installation

Coming soon :)

## License

MIT
